@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2003 by Sbastien Laot                                 *
+ *   Copyright (C) 2003 by Sébastien Laoût                                 *
  *   slaout@linux62.org                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,40 +21,41 @@
 #ifndef EXPORTERDIALOG_H
 #define EXPORTERDIALOG_H
 
-#include <kdialogbase.h>
+#include <KDialog>
 
-class KURLRequester;
+class KUrlRequester;
 class QCheckBox;
 class QString;
 
-class Basket;
+class BasketView;
 
 /**
-  * @author Sbastien Laot
+  * @author Sébastien Laoût
   */
-class ExporterDialog : public KDialogBase
+class ExporterDialog : public KDialog
 {
-  Q_OBJECT
-  public:
-	ExporterDialog(Basket *basket, QWidget *parent = 0, const char *name = 0);
-	~ExporterDialog();
-	QString filePath();
-	bool    embedLinkedFiles();
-	bool    embedLinkedFolders();
-	bool    erasePreviousFiles();
-	bool    formatForImpression();
-	void show();
-  protected slots:
-	void slotOk();
-	void load();
-	void save();
-  private:
-	Basket        *m_basket;
-	KURLRequester *m_url;
-	QCheckBox     *m_embedLinkedFiles;
-	QCheckBox     *m_embedLinkedFolders;
-	QCheckBox     *m_erasePreviousFiles;
-	QCheckBox     *m_formatForImpression;
+    Q_OBJECT
+public:
+    ExporterDialog(BasketView *basket, QWidget *parent = 0, const char *name = 0);
+    ~ExporterDialog();
+    QString filePath();
+    bool    embedLinkedFiles();
+    bool    embedLinkedFolders();
+    bool    erasePreviousFiles();
+    bool    formatForImpression();
+    void show();
+
+protected slots:
+    void load();
+    void save();
+    void accept();
+private:
+    BasketView    *m_basket;
+    KUrlRequester *m_url;
+    QCheckBox     *m_embedLinkedFiles;
+    QCheckBox     *m_embedLinkedFolders;
+    QCheckBox     *m_erasePreviousFiles;
+    QCheckBox     *m_formatForImpression;
 };
 
 #endif // EXPORTERDIALOG_H
