@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2003 by Sbastien Laot                                 *
+ *   Copyright (C) 2003 by Sébastien Laoût                                 *
  *   slaout@linux62.org                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -28,20 +28,21 @@
 // ShiftMask, ControlMask and Mod1Mask are defined in <X11/X.h>
 #if defined Q_WS_X11 && ! defined K_WS_QTONLY
 #include <X11/Xlib.h> // schroder
+#include <QX11Info>
 #endif
 
 void Keyboard::pressedKeys(bool &shiftPressed, bool &controlPressed)
 {
 #if defined Q_WS_X11 && ! defined K_WS_QTONLY
-	Window root;
-	Window child;
-	int root_x, root_y, win_x, win_y;
-	uint keybstate;
-	XQueryPointer( qt_xdisplay(), qt_xrootwin(), &root, &child,
-	               &root_x, &root_y, &win_x, &win_y, &keybstate );
+    Window root;
+    Window child;
+    int root_x, root_y, win_x, win_y;
+    uint keybstate;
+    XQueryPointer(QX11Info::display(), QX11Info::appRootWindow(), &root, &child,
+                  &root_x, &root_y, &win_x, &win_y, &keybstate);
 
-	shiftPressed   = keybstate & ShiftMask;
-	controlPressed = keybstate & ControlMask;
+    shiftPressed   = keybstate & ShiftMask;
+    controlPressed = keybstate & ControlMask;
 #endif
 }
 
@@ -50,16 +51,16 @@ void Keyboard::pressedKeys(bool &shiftPressed, bool &controlPressed)
 bool Keyboard::shiftPressed()
 {
 #if defined Q_WS_X11 && ! defined K_WS_QTONLY
-	Window root;
-	Window child;
-	int root_x, root_y, win_x, win_y;
-	uint keybstate;
-	XQueryPointer( qt_xdisplay(), qt_xrootwin(), &root, &child,
-	               &root_x, &root_y, &win_x, &win_y, &keybstate );
+    Window root;
+    Window child;
+    int root_x, root_y, win_x, win_y;
+    uint keybstate;
+    XQueryPointer(QX11Info::display(), QX11Info::appRootWindow(), &root, &child,
+                  &root_x, &root_y, &win_x, &win_y, &keybstate);
 
-	return (keybstate & ShiftMask) != 0;
+    return (keybstate & ShiftMask) != 0;
 #else
-	return false;
+    return false;
 #endif
 }
 
@@ -68,16 +69,16 @@ bool Keyboard::shiftPressed()
 bool Keyboard::controlPressed()
 {
 #if defined Q_WS_X11 && ! defined K_WS_QTONLY
-	Window root;
-	Window child;
-	int root_x, root_y, win_x, win_y;
-	uint keybstate;
-	XQueryPointer( qt_xdisplay(), qt_xrootwin(), &root, &child,
-	               &root_x, &root_y, &win_x, &win_y, &keybstate );
+    Window root;
+    Window child;
+    int root_x, root_y, win_x, win_y;
+    uint keybstate;
+    XQueryPointer(QX11Info::display(), QX11Info::appRootWindow(), &root, &child,
+                  &root_x, &root_y, &win_x, &win_y, &keybstate);
 
-	return (keybstate & ControlMask) != 0;
+    return (keybstate & ControlMask) != 0;
 #else
-	return false;
+    return false;
 #endif
 }
 
@@ -86,16 +87,16 @@ bool Keyboard::controlPressed()
 bool Keyboard::altPressed()
 {
 #if defined Q_WS_X11 && ! defined K_WS_QTONLY
-	Window root;
-	Window child;
-	int root_x, root_y, win_x, win_y;
-	uint keybstate;
-	XQueryPointer( qt_xdisplay(), qt_xrootwin(), &root, &child,
-	               &root_x, &root_y, &win_x, &win_y, &keybstate );
+    Window root;
+    Window child;
+    int root_x, root_y, win_x, win_y;
+    uint keybstate;
+    XQueryPointer(QX11Info::display(), QX11Info::appRootWindow(), &root, &child,
+                  &root_x, &root_y, &win_x, &win_y, &keybstate);
 
-	return (keybstate & Mod1Mask) != 0;
+    return (keybstate & Mod1Mask) != 0;
 #else
-	return false;
+    return false;
 #endif
 }
 
@@ -120,7 +121,7 @@ uint KApplication::keyboardModifiers()
     Window child;
     int root_x, root_y, win_x, win_y;
     uint keybstate;
-    XQueryPointer( qt_xdisplay(), qt_xrootwin(), &root, &child,
+    XQueryPointer( QX11Info::display(), QX11Info::appRootWindow(), &root, &child,
                    &root_x, &root_y, &win_x, &win_y, &keybstate );
     return keybstate & 0x00ff;
 }
